@@ -1,5 +1,5 @@
 __title__ = 'Meraki_Auto_Sync'
-__description__ = 'Auto Sync Meraki Network Dashboard cross Orginization based on network tags for master and targersr'
+__description__ = 'Auto Sync Meraki Network Dashboard cross Orginization based on network tags for master and target'
 __url__ = 'http://devnet.cisco.com'
 __download_url__ = 'https://devnet.cisco.com'
 __author__ = 'Josh Lipton'
